"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _messages = require("./messages");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function mergeWithDefaults(date, number, formatOverrides, messages) {
  if (date.__original) {
    var _date$__original = date.__original;
    date = _date$__original[0];
    number = _date$__original[1];
  }

  number = number || date;
  return {
    messages: (0, _messages.getMessages)(messages),

    get datePropType() {
      return date.propType;
    },

    get numberPropType() {
      return number.propType;
    },

    get firstOfWeek() {
      return date.firstOfWeek;
    },

    formatDate: function formatDate(value, format) {
      return date.formatDate(value, formatOverrides[format] || date.dateFormats[format] || format);
    },
    parseDate: date.parseDate.bind(date),
    formatNumber: function formatNumber(value, format) {
      return number.formatNumber(value, formatOverrides[format] || number.numberFormats[format] || format);
    },
    parseNumber: number.parseNumber.bind(number),
    decimalChar: number.decimalChar.bind(number),
    precision: number.precision.bind(number),
    __original: [date, number]
  };
}

var LocalizerContext = _react.default.createContext(process.env.NODE_ENV === 'test' && {
  date: global.TEST_LOCALIZER
});

var propTypes = {
  /**
   * A single localizer instance for both date and number localization.
   *
   * @type {Localizer}
   */
  localizer: function localizer() {},

  /**
   * A date-only localizer instance, should be combined with `numberLocalizer` if both are needed.
   *
   * @type {Localizer}
   */
  dateLocalizer: function dateLocalizer() {},

  /**
   * A number-only localizer instance, should be combined with `dateLocalizer` if both are needed.
   *
   * @type {Localizer}
   */
  numberLocalizer: function numberLocalizer() {}
};

var Provider = function Provider(_ref) {
  var localizer = _ref.localizer,
      dateLocalizer = _ref.dateLocalizer,
      numberLocalizer = _ref.numberLocalizer,
      children = _ref.children;
  return _react.default.createElement(LocalizerContext.Provider, {
    value: {
      date: dateLocalizer || localizer,
      number: numberLocalizer
    }
  }, children);
};

Provider.propTypes = propTypes;
Provider.Consumer = LocalizerContext.Consumer;

Provider.withLocalizer = function (Component) {
  var render = function render(_ref2, ref) {
    var messages = _ref2.messages,
        formats = _ref2.formats,
        props = _objectWithoutPropertiesLoose(_ref2, ["messages", "formats"]);

    return _react.default.createElement(LocalizerContext.Consumer, null, function (_temp) {
      var _ref3 = _temp === void 0 ? {} : _temp,
          date = _ref3.date,
          number = _ref3.number;

      return _react.default.createElement(Component, _extends({
        ref: ref
      }, props, {
        formats: formats,
        localizer: mergeWithDefaults(date, number, formats || {}, messages)
      }));
    });
  };

  render.displayName = "withLocalizer(" + Component.name + ")";
  return _extends(_react.default.forwardRef(render), {
    Component: Component
  });
};

var _default = Provider;
exports.default = _default;
module.exports = exports["default"];